@@ -603,16 +603,9 @@ void KSegWindow::filePrint()
 
     p.setWindow(docSize);
 
+    p.setClipRect(docSize, QPainter::CoordPainter);
+
     view->getDocument()->print(p, ViewTransform(view->getOffsetX(), view->getOffsetY(), view->getZoom()));
-
-    p.setViewport(viewPort);
-    p.setWindow(viewPort);
-
-    p.eraseRect(-1000, -1000, 2000 + viewPort.width(), 1000 + vp.top() - 5);
-    p.eraseRect(-1000, -1000, 1000 + vp.left() - 5, 2000 + viewPort.height());
-    p.eraseRect(-1000, vp.bottom() + 6, 2000 + viewPort.width(), viewPort.bottom() - vp.bottom() + 1000);
-    p.eraseRect(vp.right() + 6, -1000, viewPort.right() - vp.right() + 1000, 2000 + viewPort.height());
-
 #else
     QRect docSize = view->getDocument()->getSize(ViewTransform(0, 0, 1));
 
@@ -953,10 +946,10 @@ void KSegWindow::help()
 void KSegWindow::helpAbout()
 {
   QMessageBox::about(this, tr("About KSEG"),
-		     tr("KSEG v0.4\n"
-			"Copyright (C) 1999-2003 Ilya Baran\n"
+		     tr("KSEG v%1\n"
+			"Copyright (C) %2 Ilya Baran\n"
 			"http://www.mit.edu/~ibaran\n"
-			"ibaran@mit.edu"));
+			"ibaran@mit.edu").arg("0.401").arg("1999-2004"));
 }
 
 
