@@ -542,8 +542,6 @@ void box::draw(QPainter &p, int x, int y, QFont *f_, QColor *bc, QColor *fc)
 
   QRect tmp;
   int i;
-  QString tmpstr; //a one-char string for operators
-  tmpstr[1] = 0;
 
 #if 0  // draw bounding boxes?
   p.setPen(QColor(255, 0, 0));
@@ -591,8 +589,7 @@ void box::draw(QPainter &p, int x, int y, QFont *f_, QColor *bc, QColor *fc)
   case EQUAL:
   case MORE:
   case LESS:
-    tmpstr[0] = type;
-    p.drawText(x + relx, y + rely, tmpstr); //just draw the operator
+    p.drawText(x + relx, y + rely, QChar(type)); //just draw the operator
     break;
 
   case CAT: //children are already drawn.
