@@ -1008,12 +1008,12 @@ Items</source>
         <translation type="unfinished">&amp;Einstellungen</translation>
     </message>
     <message>
-        <source>KSEG v0.4
-Copyright (C) 1999-2003 Ilya Baran
+        <source>KSEG v%1
+Copyright (C) %2 Ilya Baran
 http://www.mit.edu/~ibaran
 ibaran@mit.edu</source>
-        <translation type="unfinished">KSEG v0.4
-Copyright (C) 1999-2003 Ilya Baran
+        <translation type="unfinished">KSEG v%1
+Copyright (C) %2 Ilya Baran
 http://www.mit.edu/~ibaran
 ibaran@mit.edu</translation>
     </message>
@@ -1035,7 +1035,7 @@ ibaran@mit.edu</translation>
     </message>
     <message>
         <source>&amp;Pan</source>
-        <translation type="unfinished">Verkleinern (&amp;P)</translation>
+        <translation type="unfinished">Skizze Verschieben (&amp;P)</translation>
     </message>
     <message>
         <source>&amp;View</source>
