@@ -1010,12 +1010,12 @@ Items</translation>
         <translation type="unfinished">Pr&amp;eferences...</translation>
     </message>
     <message>
-        <source>KSEG v0.4
-Copyright (C) 1999-2003 Ilya Baran
+        <source>KSEG v%1
+Copyright (C) %2 Ilya Baran
 http://www.mit.edu/~ibaran
 ibaran@mit.edu</source>
-        <translation type="unfinished">KSEG v0.4
-Copyright (C) 1999-2003 Ilya Baran
+        <translation type="unfinished">KSEG v%1
+Copyright (C) %2 Ilya Baran
 http://www.mit.edu/~ibaran
 ibaran@mit.edu</translation>
     </message>
