@@ -1022,12 +1022,12 @@ invisibles </translation>
         <translation>&amp;Grupos de selección...</translation>
     </message>
     <message>
-        <source>KSEG v0.4
-Copyright (C) 1999-2003 Ilya Baran
+        <source>KSEG v%1
+Copyright (C) %2 Ilya Baran
 http://www.mit.edu/~ibaran
 ibaran@mit.edu</source>
-        <translation>KSEG v0.4
-Derechos reservados por Ilya Baran (1999-2003).
+        <translation>KSEG v%1
+Derechos reservados por Ilya Baran (%2).
 http://www.mit.edu/~ibaran
 ibaran@mit.edu</translation>
     </message>
