@@ -348,15 +348,15 @@
     </message>
     <message>
         <source>%1 is the endpoint of %2</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">%1 e&apos; il punto finale di %2</translation>
     </message>
     <message>
         <source>%1 is the 2nd endpoint of %2</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">%1 e&apos; il secondo punto finale di %2</translation>
     </message>
     <message>
         <source>%1 is the center of %2</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">%1 e&apos; il centro di %2</translation>
     </message>
 </context>
 <context>
@@ -390,11 +390,11 @@
     </message>
     <message>
         <source>Border Selection</source>
-        <translation type="unfinished">Selezione del bordo</translation>
+        <translation type="unfinished">Bordo dei selezionati</translation>
     </message>
     <message>
         <source>Blinking Selection</source>
-        <translation type="unfinished">Selezione lampeggio</translation>
+        <translation type="unfinished">Lampeggio dei Selezionati</translation>
     </message>
     <message>
         <source>OK</source>
@@ -469,9 +469,9 @@
         <source>Affect
 Invisible
 Items</source>
-        <translation type="unfinished">Agisce
-Invisibile
-Elementi</translation>
+        <translation type="unfinished">Azione
+sugli elementi
+invisibili</translation>
     </message>
     <message>
         <source>Hold SHIFT and click to add to current selection</source>
@@ -479,7 +479,7 @@ Elementi</translation>
     </message>
     <message>
         <source>Whether the &quot;All &lt;Type&gt;&quot; groups also (de)select invisible objects</source>
-        <translation type="unfinished">Se i gruppi &quot;Tutto &lt;Tipo&gt;&quot;  (de)seleziona anche gli oggetti invisibili</translation>
+        <translation type="unfinished">Nei gruppi &quot;Tutti &lt;Tipo&gt;&quot;  (de)selezionare anche gli oggetti invisibili</translation>
     </message>
     <message>
         <source>All Points</source>
@@ -515,11 +515,11 @@ Elementi</translation>
     </message>
     <message>
         <source>All Arc Sectors</source>
-        <translation type="unfinished">Tutti i Settori dell&apos;Arco</translation>
+        <translation type="unfinished">Tutti i Settori circolari</translation>
     </message>
     <message>
         <source>All Arc Segments</source>
-        <translation type="unfinished">Tutti i Segmenti dell&apos;Arco</translation>
+        <translation type="unfinished">Tutti i Segmenti circolari</translation>
     </message>
     <message>
         <source>All Loci</source>
@@ -588,11 +588,11 @@ Elementi</translation>
     </message>
     <message>
         <source>Pan</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Sposta</translation>
     </message>
     <message>
         <source>Zoom</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Zoom</translation>
     </message>
 </context>
 <context>
@@ -703,7 +703,7 @@ Elementi</translation>
     </message>
     <message>
         <source>&amp;Hide Objects</source>
-        <translation type="unfinished">&amp;Cancella gli oggetti</translation>
+        <translation type="unfinished">&amp;Nascondi gli oggetti</translation>
     </message>
     <message>
         <source>&amp;Unhide All</source>
@@ -867,27 +867,27 @@ Elementi</translation>
     </message>
     <message>
         <source>Make &amp;Normal</source>
-        <translation type="unfinished">Fai &amp;Normale</translation>
+        <translation type="unfinished">Rendi &amp;Normale</translation>
     </message>
     <message>
         <source>Make &amp;Given</source>
-        <translation type="unfinished">Esegui &amp;Dato</translation>
+        <translation type="unfinished">Rendi &amp;Dato</translation>
     </message>
     <message>
         <source>Make &amp;Final</source>
-        <translation type="unfinished">Esegui &amp;Finale</translation>
+        <translation type="unfinished">Rendi &amp;Finale</translation>
     </message>
     <message>
         <source>Make &amp;Initial</source>
-        <translation type="unfinished">Fai &amp;Iniziale</translation>
+        <translation type="unfinished">Rendi &amp;Iniziale</translation>
     </message>
     <message>
         <source>&amp;Recurse</source>
-        <translation type="unfinished">&amp;Ricorsione</translation>
+        <translation type="unfinished">&amp;Ciclo ricorsivo</translation>
     </message>
     <message>
         <source>&amp;Quick Play</source>
-        <translation type="unfinished">&amp;Esegui velocemente</translation>
+        <translation type="unfinished">&amp;Esegui direttamente</translation>
     </message>
     <message>
         <source>&amp;About...</source>
@@ -1019,15 +1019,15 @@ Elementi</translation>
     </message>
     <message>
         <source>Selection &amp;Groups...</source>
-        <translation type="unfinished">Scegli &amp;Lingua...</translation>
+        <translation type="unfinished">Gruppi &amp;Selezionati...</translation>
     </message>
     <message>
-        <source>KSEG v0.4
-Copyright (C) 1999-2003 Ilya Baran
+        <source>KSEG v%1
+Copyright (C) %2 Ilya Baran
 http://www.mit.edu/~ibaran
 ibaran@mit.edu</source>
-        <translation type="unfinished">KSEG v0.4
-Copyright (C) 1999-2003 Ilya Baran
+        <translation type="unfinished">KSEG v%1
+Copyright (C) %2 Ilya Baran
 http://www.mit.edu/~ibaran
 ibaran@mit.edu</translation>
     </message>
@@ -1037,7 +1037,7 @@ ibaran@mit.edu</translation>
     </message>
     <message>
         <source>&amp;Pan</source>
-        <translation type="unfinished">&amp;Pannello</translation>
+        <translation type="unfinished">&amp;Spostamento</translation>
     </message>
     <message>
         <source>&amp;View</source>
