@@ -1010,12 +1010,12 @@ objecten</translation>
         <translation>&amp;Voorkeuren...</translation>
     </message>
     <message>
-        <source>KSEG v0.4
-Copyright (C) 1999-2003 Ilya Baran
+        <source>KSEG v%1
+Copyright (C) %2 Ilya Baran
 http://www.mit.edu/~ibaran
 ibaran@mit.edu</source>
-        <translation>KSEG v0.4
-Copyright (C) 1999-2003 Ilya Baran
+        <translation>KSEG v%1
+Copyright (C) %2 Ilya Baran
 http://www.mit.edu/~ibaran
 ibaran@mit.edu</translation>
     </message>
